@@ -1,16 +1,15 @@
 use std::convert::{TryFrom, TryInto};
+use ustr::Ustr;
 
 use super::NonOpt;
 
-use crate::err::{ConstructError, Error, SpecialError};
+use crate::err::Error;
+use crate::gstr;
 use crate::opt::*;
-use crate::set::{CreateInfo, Creator};
+use crate::set::CreateInfo;
+use crate::set::Creator;
 use crate::uid::Uid;
-use crate::Ustr;
 
-pub fn current_type() -> Ustr {
-    Ustr::from("c")
-}
 pub trait Cmd: NonOpt {}
 
 #[derive(Debug)]
@@ -54,7 +53,7 @@ impl NonOpt for CmdOpt {}
 
 impl Type for CmdOpt {
     fn get_type_name(&self) -> Ustr {
-        current_type()
+        CmdCreator::type_name()
     }
 
     fn is_deactivate_style(&self) -> bool {
@@ -70,7 +69,7 @@ impl Type for CmdOpt {
 
     fn check(&self) -> Result<()> {
         if !(self.get_optional() || self.has_value()) {
-            Err(SpecialError::OptionForceRequired(self.get_hint().to_owned()).into())
+            Err(Error::sp_option_force_require(self.get_hint()))
         } else {
             Ok(())
         }
@@ -121,7 +120,7 @@ impl Name for CmdOpt {
     }
 
     fn get_prefix(&self) -> Ustr {
-        Ustr::from("")
+        gstr("")
     }
 
     fn set_name(&mut self, string: Ustr) {
@@ -232,9 +231,15 @@ impl Help for CmdOpt {
 #[derive(Debug, Default, Clone)]
 pub struct CmdCreator;
 
+impl CmdCreator {
+    pub fn type_name() -> Ustr {
+        gstr("c")
+    }
+}
+
 impl Creator for CmdCreator {
     fn get_type_name(&self) -> Ustr {
-        current_type()
+        Self::type_name()
     }
 
     fn is_support_deactivate_style(&self) -> bool {
@@ -244,10 +249,9 @@ impl Creator for CmdCreator {
     fn create_with(&self, create_info: CreateInfo) -> Result<Box<dyn Opt>> {
         if create_info.get_support_deactivate_style() {
             if !self.is_support_deactivate_style() {
-                return Err(ConstructError::NotSupportDeactivateStyle(
-                    create_info.get_name().to_owned(),
-                )
-                .into());
+                return Err(Error::opt_unsupport_deactivate_style(
+                    create_info.get_name(),
+                ));
             }
         }
         assert_eq!(create_info.get_type_name(), self.get_type_name());
@@ -266,17 +270,17 @@ mod test {
     fn make_type_cmd_work() {
         let creator = CmdCreator::default();
 
-        assert_eq!(creator.get_type_name(), current_type());
+        assert_eq!(creator.get_type_name(), CmdCreator::type_name());
         // cmd not support deactivate style
         assert_eq!(creator.is_support_deactivate_style(), false);
 
-        let mut ci = CreateInfo::parse(Ustr::from("cmd=c"), &[]).unwrap();
+        let mut ci = CreateInfo::parse(gstr("cmd=c"), &[]).unwrap();
 
         ci.set_uid(1);
 
         let mut cmd = creator.create_with(ci).unwrap();
 
-        assert_eq!(cmd.get_type_name(), current_type());
+        assert_eq!(cmd.get_type_name(), CmdCreator::type_name());
         assert_eq!(cmd.is_deactivate_style(), false);
         assert_eq!(cmd.match_style(Style::Cmd), true);
         assert_eq!(cmd.check().is_err(), true);
@@ -307,17 +311,17 @@ mod test {
         assert_eq!(cmd.get_index(), Some(&OptIndex::forward(1)));
         assert_eq!(cmd.match_index(6, 9), false);
 
-        assert_eq!(cmd.get_name(), Ustr::from("cmd"));
-        assert_eq!(cmd.get_prefix(), Ustr::from(""));
+        assert_eq!(cmd.get_name(), gstr("cmd"));
+        assert_eq!(cmd.get_prefix(), gstr(""));
         assert_eq!(cmd.match_name("www".into()), false);
         assert_eq!(cmd.match_name("cmd".into()), true);
         assert_eq!(cmd.match_prefix("--".into()), false);
         assert_eq!(cmd.match_prefix("".into()), false);
-        cmd.set_name(Ustr::from("cmd1"));
-        cmd.set_prefix(Ustr::from("+"));
+        cmd.set_name(gstr("cmd1"));
+        cmd.set_prefix(gstr("+"));
         assert_eq!(cmd.match_name("www".into()), false);
         assert_eq!(cmd.match_name("cmd1".into()), true);
-        assert_eq!(cmd.get_name(), Ustr::from("cmd1"));
+        assert_eq!(cmd.get_name(), gstr("cmd1"));
         assert_eq!(cmd.match_prefix("+".into()), false);
         assert_eq!(cmd.match_prefix("".into()), false);
 
