@@ -1,15 +1,13 @@
 use std::convert::{TryFrom, TryInto};
+use ustr::Ustr;
 
 use super::NonOpt;
-use crate::err::{ConstructError, Error, SpecialError};
+use crate::err::Error;
+use crate::gstr;
 use crate::opt::*;
-use crate::set::{CreateInfo, Creator};
+use crate::set::CreateInfo;
+use crate::set::Creator;
 use crate::uid::Uid;
-use crate::Ustr;
-
-pub fn current_type() -> Ustr {
-    Ustr::from("m")
-}
 
 pub trait Main: NonOpt {}
 
@@ -51,7 +49,7 @@ impl NonOpt for MainOpt {}
 
 impl Type for MainOpt {
     fn get_type_name(&self) -> Ustr {
-        current_type()
+        MainCreator::type_name()
     }
 
     fn is_deactivate_style(&self) -> bool {
@@ -67,7 +65,7 @@ impl Type for MainOpt {
 
     fn check(&self) -> Result<()> {
         if !(self.get_optional() || self.has_value()) {
-            Err(SpecialError::OptionForceRequired(self.get_hint().to_owned()).into())
+            Err(Error::sp_option_force_require(self.get_hint()))
         } else {
             Ok(())
         }
@@ -118,7 +116,7 @@ impl Name for MainOpt {
     }
 
     fn get_prefix(&self) -> Ustr {
-        Ustr::from("")
+        gstr("")
     }
 
     fn set_name(&mut self, string: Ustr) {
@@ -223,9 +221,15 @@ impl Help for MainOpt {
 #[derive(Debug, Default, Clone)]
 pub struct MainCreator;
 
+impl MainCreator {
+    pub fn type_name() -> Ustr {
+        gstr("m")
+    }
+}
+
 impl Creator for MainCreator {
     fn get_type_name(&self) -> Ustr {
-        current_type()
+        MainCreator::type_name()
     }
 
     fn is_support_deactivate_style(&self) -> bool {
@@ -235,10 +239,9 @@ impl Creator for MainCreator {
     fn create_with(&self, create_info: CreateInfo) -> Result<Box<dyn Opt>> {
         if create_info.get_support_deactivate_style() {
             if !self.is_support_deactivate_style() {
-                return Err(ConstructError::NotSupportDeactivateStyle(
-                    create_info.get_name().to_owned(),
-                )
-                .into());
+                return Err(Error::opt_unsupport_deactivate_style(
+                    create_info.get_name(),
+                ));
             }
         }
 
@@ -259,17 +262,17 @@ mod test {
     fn make_type_main_work() {
         let creator = MainCreator::default();
 
-        assert_eq!(creator.get_type_name(), current_type());
+        assert_eq!(creator.get_type_name(), MainCreator::type_name());
         // main not support deactivate style
         assert_eq!(creator.is_support_deactivate_style(), false);
 
-        let mut ci = CreateInfo::parse(Ustr::from("main=m"), &[]).unwrap();
+        let mut ci = CreateInfo::parse(gstr("main=m"), &[]).unwrap();
 
         ci.set_uid(1);
 
         let mut main = creator.create_with(ci).unwrap();
 
-        assert_eq!(main.get_type_name(), current_type());
+        assert_eq!(main.get_type_name(), MainCreator::type_name());
         assert_eq!(main.is_deactivate_style(), false);
         assert_eq!(main.match_style(Style::Main), true);
         assert_eq!(main.check().is_err(), false);
@@ -298,14 +301,14 @@ mod test {
         assert_eq!(main.get_index(), None);
         assert_eq!(main.match_index(6, 9), true);
 
-        assert_eq!(main.get_name(), Ustr::from("main"));
-        assert_eq!(main.get_prefix(), Ustr::from(""));
+        assert_eq!(main.get_name(), gstr("main"));
+        assert_eq!(main.get_prefix(), gstr(""));
         assert_eq!(main.match_name("www".into()), true);
         assert_eq!(main.match_name("main".into()), true);
         assert_eq!(main.match_prefix("--".into()), false);
         assert_eq!(main.match_prefix("".into()), false);
-        main.set_name(Ustr::from("main1"));
-        main.set_prefix(Ustr::from("+"));
+        main.set_name(gstr("main1"));
+        main.set_prefix(gstr("+"));
         assert_eq!(main.match_name("www".into()), true);
         assert_eq!(main.match_name("main1".into()), true);
         assert_eq!(main.get_name(), "main1");
