@@ -1,15 +1,13 @@
 use std::convert::{TryFrom, TryInto};
 use std::mem::take;
+use ustr::Ustr;
 
-use crate::err::{ConstructError, Error, ParserError, SpecialError};
+use crate::err::Error;
+use crate::gstr;
 use crate::opt::*;
-use crate::set::{CreateInfo, Creator};
+use crate::set::CreateInfo;
+use crate::set::Creator;
 use crate::uid::Uid;
-use crate::Ustr;
-
-pub fn current_type() -> Ustr {
-    Ustr::from("s")
-}
 
 pub trait Str: Opt {}
 
@@ -40,10 +38,9 @@ impl TryFrom<CreateInfo> for StrOpt {
     fn try_from(value: CreateInfo) -> Result<Self> {
         let mut ci = value;
         let help_info = HelpInfo::from(&mut ci);
-        let prefix = ci.get_prefix().ok_or(ConstructError::MissingOptionPrefix(
-            format!("{}", ci.get_name()),
-            format!("{}", ci.get_type_name()),
-        ))?;
+        let prefix = ci
+            .get_prefix()
+            .ok_or(Error::opt_missing_prefix(ci.get_name(), ci.get_type_name()))?;
 
         Ok(Self {
             uid: ci.get_uid(),
@@ -65,7 +62,7 @@ impl Opt for StrOpt {}
 
 impl Type for StrOpt {
     fn get_type_name(&self) -> Ustr {
-        current_type()
+        StrCreator::type_name()
     }
 
     fn is_deactivate_style(&self) -> bool {
@@ -81,7 +78,7 @@ impl Type for StrOpt {
 
     fn check(&self) -> Result<()> {
         if !(self.get_optional() || self.has_value()) {
-            Err(SpecialError::OptionForceRequired(self.get_hint().to_owned()).into())
+            Err(Error::sp_option_force_require(self.get_hint()))
         } else {
             Ok(())
         }
@@ -121,11 +118,10 @@ impl Callback for StrOpt {
     fn set_callback_ret(&mut self, ret: Option<OptValue>) -> Result<()> {
         if let Some(ret) = ret {
             if !ret.is_str() {
-                return Err(ParserError::InvalidReturnValueOfCallback(format!(
+                return Err(Error::opt_invalid_ret_value(format!(
                     "excepted OptValue::Str, found {:?}",
                     ret
-                ))
-                .into());
+                )));
             }
             self.set_value(ret);
         }
@@ -261,9 +257,15 @@ impl Help for StrOpt {
 #[derive(Debug, Default, Clone)]
 pub struct StrCreator;
 
+impl StrCreator {
+    pub fn type_name() -> Ustr {
+        gstr("s")
+    }
+}
+
 impl Creator for StrCreator {
     fn get_type_name(&self) -> Ustr {
-        current_type()
+        StrCreator::type_name()
     }
 
     fn is_support_deactivate_style(&self) -> bool {
@@ -273,10 +275,9 @@ impl Creator for StrCreator {
     fn create_with(&self, create_info: CreateInfo) -> Result<Box<dyn Opt>> {
         if create_info.get_support_deactivate_style() {
             if !self.is_support_deactivate_style() {
-                return Err(ConstructError::NotSupportDeactivateStyle(
-                    create_info.get_name().to_owned(),
-                )
-                .into());
+                return Err(Error::opt_unsupport_deactivate_style(
+                    create_info.get_name(),
+                ));
             }
         }
 
