@@ -1,12 +1,13 @@
-pub mod check;
-pub mod delay_parser;
-pub mod pre_parser;
-pub mod simple_parser;
-pub mod state;
+mod check;
+mod delay_parser;
+mod pre_parser;
+mod simple_parser;
+mod state;
 pub(crate) mod testutil;
 
 use std::cell::RefCell;
 use std::fmt::Debug;
+use ustr::Ustr;
 
 use crate::arg::Argument;
 use crate::err::Result;
@@ -16,11 +17,14 @@ use crate::uid::Uid;
 
 pub(crate) use std::collections::hash_map::Iter as HashMapIter;
 
+pub use check::default_nonopt_check;
+pub use check::default_opt_check;
+pub use check::default_post_check;
+pub use check::default_pre_check;
 pub use delay_parser::DelayParser;
 pub use pre_parser::PreParser;
 pub use simple_parser::SimpleParser;
 pub use state::ParserState;
-use ustr::Ustr;
 
 #[derive(Debug)]
 pub struct OptValueKeeper {
