@@ -10,11 +10,19 @@ use super::ParserState;
 
 use crate::arg::Argument;
 use crate::err::Result;
-use crate::opt::{OptCallback, OptValue, Style};
-use crate::proc::{Info, Matcher, NonOptMatcher, OptMatcher, Proc};
-use crate::set::{OptionInfo, Set};
-use crate::uid::{Generator, Uid};
-use crate::Ustr;
+use crate::opt::OptCallback;
+use crate::opt::OptValue;
+use crate::opt::Style;
+use crate::proc::Info;
+use crate::proc::Matcher;
+use crate::proc::NonOptMatcher;
+use crate::proc::OptMatcher;
+use crate::proc::Proc;
+use crate::set::OptionInfo;
+use crate::set::Set;
+use crate::uid::Generator;
+use crate::uid::Uid;
+use ustr::Ustr;
 
 #[derive(Debug, Default)]
 pub struct PreParser<G>
@@ -433,12 +441,12 @@ mod test {
         assert_eq!(
             parser.get_noa(),
             &[
-                Ustr::from("p"),
-                Ustr::from("pos2"),
-                Ustr::from("pos3"),
-                Ustr::from("pos4"),
-                Ustr::from("pos5"),
-                Ustr::from("--unknow-opt")
+                gstr("p"),
+                gstr("pos2"),
+                gstr("pos3"),
+                gstr("pos4"),
+                gstr("pos5"),
+                gstr("--unknow-opt")
             ]
         );
         Ok(())
