@@ -9,13 +9,21 @@ use super::Parser;
 use super::ParserState;
 
 use crate::arg::Argument;
-use crate::err;
+use crate::err::Error;
 use crate::err::Result;
-use crate::opt::{OptCallback, OptValue, Style};
-use crate::proc::{Info, Matcher, NonOptMatcher, OptMatcher, Proc};
-use crate::set::{OptionInfo, Set};
-use crate::uid::{Generator, Uid};
-use crate::Ustr;
+use crate::opt::OptCallback;
+use crate::opt::OptValue;
+use crate::opt::Style;
+use crate::proc::Info;
+use crate::proc::Matcher;
+use crate::proc::NonOptMatcher;
+use crate::proc::OptMatcher;
+use crate::proc::Proc;
+use crate::set::OptionInfo;
+use crate::set::Set;
+use crate::uid::Generator;
+use crate::uid::Uid;
+use ustr::Ustr;
 
 #[derive(Debug)]
 pub struct SimpleParser<G>
@@ -133,11 +141,9 @@ where
                     if !matched {
                         // if current ARG is like an option, but it not matched
                         if self.strict {
-                            return Err(err::SpecialError::InvalidOptionName(format!(
-                                "{}",
-                                arg.current.unwrap_or_default().as_str()
-                            ))
-                            .into());
+                            return Err(Error::sp_invalid_option_name(
+                                arg.current.unwrap_or_default().as_ref(),
+                            ));
                         }
                     }
                 }
