@@ -1,13 +1,33 @@
-use super::{Commit, Filter, FilterMut, Uid};
-use super::{CreateInfo, Creator, FilterInfo, Set};
-use super::{CreatorSet, OptionSet, PrefixSet};
-use super::{Index, IndexMut, Iter, IterMut};
-
-use crate::err::{ConstructError, Result};
+use super::Commit;
+use super::CreateInfo;
+use super::Creator;
+use super::CreatorSet;
+use super::Filter;
+use super::FilterInfo;
+use super::FilterMut;
+use super::Index;
+use super::IndexMut;
+use super::Iter;
+use super::IterMut;
+use super::OptionSet;
+use super::PrefixSet;
+use super::Set;
+use super::Uid;
+use crate::err::Error;
+use crate::err::Result;
+use crate::gstr;
+use crate::opt::ArrayCreator;
+use crate::opt::BoolCreator;
+use crate::opt::CmdCreator;
+use crate::opt::FltCreator;
+use crate::opt::IntCreator;
+use crate::opt::MainCreator;
 use crate::opt::Opt;
-use crate::opt::{ArrayCreator, BoolCreator, FltCreator, IntCreator, StrCreator, UintCreator};
-use crate::opt::{CmdCreator, MainCreator, PosCreator};
-use crate::{gstr, Ustr, UstrMap};
+use crate::opt::PosCreator;
+use crate::opt::StrCreator;
+use crate::opt::UintCreator;
+use ustr::Ustr;
+use ustr::UstrMap;
 
 #[derive(Debug, Default)]
 pub struct SimpleSet {
@@ -54,7 +74,7 @@ impl Set for SimpleSet {}
 
 impl OptionSet for SimpleSet {
     fn add_opt(&mut self, opt_str: &str) -> Result<Commit> {
-        let info = CreateInfo::parse(Ustr::from(opt_str), self.get_prefix())?;
+        let info = CreateInfo::parse(gstr(opt_str), self.get_prefix())?;
 
         debug!(%opt_str, "create option");
         Ok(Commit::new(self, info))
@@ -74,9 +94,7 @@ impl OptionSet for SimpleSet {
                 self.opt.push(opt);
                 Ok(uid)
             }
-            None => {
-                Err(ConstructError::NotSupportOptionType(format!("{}", ci.get_type_name())).into())
-            }
+            None => Err(Error::opt_unsupport_option_type(ci.get_type_name())),
         }
     }
 
